Learn R Programming

ggsced (version 0.1.6)

ggsced_condition_labels: generate_condition_labels

Description

Optional helper class to prepare condition labels (e.g., Baseline, Intervention) based on the grouping of an existing ggplot object

Usage

ggsced_condition_labels(plt, y = NULL)

Value

a data frame that can be used with a geom_text layer

Arguments

plt

ggplot object

y

ordinate of respective label (Default = last tick from plot object)