Learn R Programming

ggsced (version 0.1.6)

ggsced_name_dogleg: ggsced_name_dogleg

Description

Grobs need to have unique names lest they get accidentally overwritten. This is a convenience naming function for the 'main' phase break within a facet level.

Usage

ggsced_name_dogleg(panel, index, n_leg)

Value

a name corresponding with unique phase-change grob element

Arguments

panel

name of the parent grob

index

index of the phase change in sequence

n_leg

leg in the phase change