Learn R Programming

ggsced (version 0.1.6)

ggsced_scale_units: ggsced_scale_units

Description

Internal helper to discern exactly where a vertical would need to be placed within a specific grob (i.e., panel grob). Uses the domain and phase change location as a reference to convert to npc units for gtable and grid.

Usage

ggsced_scale_units(session_value, domain_size)

Value

A proportional value given value in a panel domain

Arguments

session_value

Session associated with phase-change line

domain_size

Total size of domain per panel specification