Learn R Programming

ggsced (version 0.1.6)

ggsced_style_x: ggsced_style_x

Description

This is a convenience element designed to support a more complete interpretation of SCED-specific style conventions through ggplot. Specifically, an axis is drawn with a specific manner of expansion to support the broken axis (i.e., non-connected x/y) expected of SCED-specific publication guidelines.

Usage

ggsced_style_x(expansion = 0, lwd = 2, col = "black")

Value

Annotation to simulate a disconnected y-axis via expansion

Arguments

expansion

Percentage of axis to pad (left/right) to break axis (Note: normalized parent units)

lwd

Width of axis line

col

Color of axis drawn (default = 'black')