ggsced_facet_labels: ggsced_facet_labels
Description
Optional helper class to prepare facet labels (e.g., Participant names) based on the faceting of an existing ggplot object
Usage
ggsced_facet_labels(plt, y = 0, x = NULL)
Value
a data frame that can be used with a geom_text layer
Arguments
- plt
ggplot object
- y
ordinate of respective label (typically very low or very high)
- x
position on the x-axis (Default = last tick from plot object)