ggsced_get_panels: ggsced_get_panels
Description
Honestly, a bit of a 'hackish' solution to extract grobs that are associated with data to be drawn. Probably fragile and specific to modern gg implementations, but probably the close we'll get. Subject to change.
Usage
ggsced_get_panels(ggplot_grobs)
Value
filtered list of grobs restricted to faceted levels
Arguments
- ggplot_grobs
list of grobs prepared by ggplotGrob